@@ -39,6 +39,7 @@ setClass("lavSampleStats",         # sample moments
         th.idx="list",
         th.names="list",           # threshold names
         slopes="list",             # slopes exo
+        mean.x="list",             # mean exo
         cov.x="list",              # variance/covariance exo
         bifreq="list",             # bivariate frequency tables
 
@@ -103,7 +104,11 @@ setClass("Model",          # MATRIX representation of the sem model
         con.lambda="numeric",
 
         nexo="integer",
-        fixed.x="logical"
+        fixed.x="logical",
+        ov.x.dummy.ov.idx="list",
+        ov.x.dummy.lv.idx="list",
+        ov.y.dummy.ov.idx="list",
+        ov.y.dummy.lv.idx="list"
 
     )
 )
@@ -135,6 +140,7 @@ setClass("lavaan",
         timing      = "list",            # timing information
         Options     = "list",            # lavaanOptions
         ParTable    = "list",            # parameter table user-specified model
+        pta         = "list",            # parameter table attributes
         Data        = "lavData",         # full data
         SampleStats = "lavSampleStats",  # sample statistics
         Model       = "Model",           # internal matrix representation
