@@ -41,9 +41,15 @@ lavaanify <- lavParTable <- function(
                       
                       as.data.frame.   = TRUE) {
 
-    # check if model is already FLAT
+
+    # check if model is already FLAT or a full parameter table
     if(is.list(model) && !is.null(model$lhs)) {
-        FLAT <- model
+        if(is.null(model$mod.idx)) {
+            warning("lavaan WARNING: input already looks like a parameter table; returning as is")
+            return(model)
+        } else {
+            FLAT <- model
+        }
     } else {
         # parse the model syntax and flatten the user-specified model
         # return a data.frame, where each line is a model element (rhs, op, lhs)
@@ -419,7 +425,7 @@ lavParseModelString <- function(model.syntax = '', as.data.frame. = FALSE,
     CON.idx  <- 0L
     MOD <- vector("list", length=0L)
     CON <- vector("list", length=0L)
-    GRP <- 0L
+    GRP <- 1L
     for(i in 1:length(model)) {
         x <- model[i]
         if(debug) {
@@ -493,7 +499,6 @@ lavParseModelString <- function(model.syntax = '', as.data.frame. = FALSE,
         # 2c if operator is ":", put it in GRP
         if(op == ":") {
             FLAT.idx <- FLAT.idx + 1L
-            GRP <- GRP + 1L
             FLAT.lhs[FLAT.idx] <- lhs
             FLAT.op[ FLAT.idx] <- op
             FLAT.rhs[FLAT.idx] <- ""
@@ -502,6 +507,7 @@ lavParseModelString <- function(model.syntax = '', as.data.frame. = FALSE,
             FLAT.label[FLAT.idx] <- ""
             FLAT.rhs.mod.idx[FLAT.idx] <- 0L
             FLAT.group[FLAT.idx] <- GRP
+            GRP <- GRP + 1L
             next
         }
     
